red1 = 196  # light red
red2 = 160
red3 = 124
red4 = 88
red5 = 52  # dark red

green1 = 46
green2 = 40
green3 = 34
green4 = 28
green5 = 22

blue1 = 51
blue2 = 45
blue3 = 39
blue4 = 33
blue5 = 27

white1 = 15
white2 = 7


from colorfulpanda.Style.Base import BaseStyle

style0 = BaseStyle(False, False, [52])
style1 = BaseStyle(False, False, [196,124,88,52])
style2 = BaseStyle(False, False, [196, 88])
style3 = BaseStyle(False, False, [196])
style4 = BaseStyle(True, True, [196])